# Movement Detector

[![Build Status](https://travis-ci.com/petioptrv/movement_detector.svg?branch=master)](https://travis-ci.com/petioptrv/movement_detector)
[![Documentation Status](https://readthedocs.org/projects/movement-detector/badge/?version=latest)](https://movement-detector.readthedocs.io/en/latest/?badge=latest)

The Movement Detector (MD) is a collection of classes enabling the detection of movement in video files. The original
purpose of the library is to enable the detection of freezing responses during behavioural experiments,
such as initially proposed by Blanchard and Blanchard 1988 [1].

However, the architecture of the classes permits the user to extend the capabilities of the library to virtually any
video-processing algorithm.

Extensive documentation can be found [here](https://movement-detector.readthedocs.io/en/latest/). Behavioural 
scientists that wish to use the library for the detection of freezing responses as quickly as possible should clone the 
[repository](https://github.com/petioptrv/movement_detector) as described in the 
[Installation](https://movement-detector.readthedocs.io/en/latest/#installation) section of the documentation, 
and follow the usage instructions in the 
[Research Scientists Workflow](https://movement-detector.readthedocs.io/en/latest/#research-scientists-workflow) 
section.


[1] Blanchard, D. C., & Blanchard, R. J. (1988). Experimental approaches to the biology of emotion. Annual review of psychology, 39(1), 43-68.
